#####################################################################
# Contains all the BGE related procedure
#####################################################################

# record physics engine movement to FCurve
def recorder():
	# tread softly, for you tread on two APIs
	from bge import logic
	from bge import render
	from bpy import data
	from bpy import context
	from bpy import ops
	
	# only record to fcurves if the user has requested it
	if context.scene.BBSolveMotion == 2:
		cont = logic.getCurrentController()
		scene = logic.getCurrentScene()
		own = cont.owner
		time = own["timer"]
		# record to a new region of the timeline
		offset = 200 + context.scene.frame_end
		
		# for all object
		for bgeOBJ in scene.objects:
			try:
				# lookup BPY object from  BGE object name
				bpyOBJ = data.objects[bgeOBJ.name]
			except:
				continue

			# ignore non-atom object (lamps, cameras, etc)
			if bpyOBJ.BBInfo:
				bpyOBJ.location = bgeOBJ.position
				bpyOBJ.select = True

		
		# jump to new position for recording
		context.scene.frame_current = int(time+offset)
		# insert keyframe
		ops.anim.keyframe_insert_menu(type=-1)
		# jump back to the playback position
		context.scene.frame_current = int(time)
		
		# end game if done
		if time > context.scene.frame_end:
			logic.endGame()
		else:
			print ("\rRecording protein motion %.0f%%" %(time/context.scene.frame_end*100), end="")
			

# translate mouse movement to camera movement
def mouse():
	from bge import logic
	from bge import render
	from bpy import context
	
	# disable mouselook if we are recording fcurves
	if context.scene.BBSolveMotion == 2:
		render.showMouse(True)
		return

	# alias
	controller = logic.getCurrentController()
	player = controller.owner
	mouse = controller.sensors["Mouse"]
	lookLeftRight = controller.actuators["LookLeftRight"]
	lookUpDown = controller.actuators["LookUpDown"]
	width = render.getWindowWidth()
	height = render.getWindowHeight()

	move = (width//2 - mouse.position[0], height//2 - mouse.position[1])
	sensitivity = 0.005

	# Amount, direction and sensitivity
	leftRight = move[0] * sensitivity
	upDown = move[1] * sensitivity
	 
	# Smooth movement
	leftRight = (player['oldLeftRight']*0.9 + leftRight*.1)
	upDown  = (player['oldUpDown']*0.9 + upDown*.1)
	 
	# set the values
	lookLeftRight.dRot = (0.0, 0.0, leftRight)
	lookLeftRight.useLocalDRot = False
	lookUpDown.dRot = (upDown, 0.0, 0.0)
	lookUpDown.useLocalDRot = True

	# Apply
	controller.activate(lookLeftRight)
	controller.activate(lookUpDown)
	 
	# Center mouse in game window
	render.setMousePosition(width//2, height//2)

	player['oldLeftRight'] = leftRight
	player['oldUpDown']= upDown
