#####################################################################
# Defines all Blender Operators
#####################################################################

from bpy import *
from .core import *
rewrite_Visualizer()
from . import BBV1
from . import BBV2
from . import BBV3
class BBOperatorImport(types.Operator):
	bl_idname = "BBOperatorImport"
	bl_label = "Import PDB"
	bl_description = "generate 3D Model"
	def invoke(self, context, event):
		try:
			context.user_preferences.edit.use_global_undo = False
			importFile()
			context.user_preferences.edit.use_global_undo = True
		except Exception as E:
			s = "Import Failed: " + str(E)
			self.report('ERROR', s)
			print (s)
			errorNotifier(text=s)
			return {'CANCELLED'}
		else:
			return{'FINISHED'}

class BBOperatorUpdate(types.Operator):
	bl_idname = "BBOperatorUpdate"
	bl_label = "Update Aminoacid List"
	bl_description = "Update Aminoacid List"
	def invoke(self, context, event):
		try:
			context.user_preferences.edit.use_global_undo = False
			session_write_aminoacids(verbose=False)
			reload(BBV1)
			reload(BBV2)
			reload(BBV3)
			context.user_preferences.edit.use_global_undo = True
		except Exception as E:
			s = "Update Failed: " + str(E)
			self.report('ERROR', s)
			print (s)
			errorNotifier(text=s)
			return {'CANCELLED'}
		else:
			return{'FINISHED'}

class BBOperatorInteractive(types.Operator):
	bl_idname = "BBOperatorInteractive"
	bl_label = "Run in Game Engine"
	bl_description = "Enter Interactive View Mode"
	def invoke(self, context, event):
		try:
			startGame()
		except Exception as E:
			s = "Start Game Failed: " + str(E)
			self.report('ERROR', s)
			print (s)
			errorNotifier(text=s)
			return {'CANCELLED'}
		else:
			return{'FINISHED'}

class BBOperatorAtomicMLP(types.Operator):
	bl_idname = "BBOperatorAtomicMLP"
	bl_label = "Atomic MLP"
	bl_description = "Visualize atomic MLP"
	def invoke(self, context, event):
		try:
			attribute_lipo_materials()
		except Exception as E:
			s = "Atomic MLP assigment failed: " + str(E)
			self.report('ERROR', s)
			print (s)
			errorNotifier(text=s)
			return {'CANCELLED'}
		else:
			return{'FINISHED'}

class BBOperatorSurface(types.Operator):
	bl_idname = "BBOperatorSurface"
	bl_label = "Show Surface"
	bl_description = "Show Surface model"
	def invoke(self, context, event):
		print("invoke surface")
		try:
			context.user_preferences.edit.use_global_undo = False
			setup()
			surface()
			context.scene.BBViewFilter = "5"
			context.user_preferences.edit.use_global_undo = True
		except Exception as E:
			s = "Generate Surface Failed: " + str(E)
			self.report('ERROR', s)
			print (s)
			errorNotifier(text=s)
			return {'CANCELLED'}
		else:
			return{'FINISHED'}


class BBOperatorMLP(types.Operator):
	bl_idname = "BBOperatorMLP"
	bl_label = "Show MLP on Surface"
	bl_description = "Calculate Molecular Lipophilicity Potential on surface"
	def invoke(self, context, event):
		try:
			context.user_preferences.edit.use_global_undo = False
			mlp(force = True)
			context.scene.BBViewFilter = "5"
			context.user_preferences.edit.use_global_undo = True
		except Exception as E:
			s = "Generate MLP visualization Failed: " + str(E)
			self.report('ERROR', s)
			print (s)
			errorNotifier(text=s)
			return {'CANCELLED'}
		else:
			return{'FINISHED'}

class BBOperatorMLPRender(types.Operator):
	bl_idname = "BBOperatorMLPRender"
	bl_label = "Render MLP to Surface"
	bl_description = "Visualize Molecular Lipophilicity Potential on surface"
	def invoke(self, context, event):
		try:
			context.user_preferences.edit.use_global_undo = False
			mlpRender()
			context.scene.BBViewFilter = "5"
			context.user_preferences.edit.use_global_undo = True
		except Exception as E:
			s = "Generate MLP visualization Failed: " + str(E)
			self.report('ERROR', s)
			print (s)
			errorNotifier(text=s)
			return {'CANCELLED'}
		else:
			return{'FINISHED'}


class BBOperatorEP(types.Operator):
	bl_idname = "BBOperatorEP"
	bl_label = "Show EP"
	bl_description = "Calculate and Visualize Electric Potential"
	def invoke(self, context, event):
		try:
			context.user_preferences.edit.use_global_undo = False
			cleanEPObjs()
			ep(animation = False)
			context.scene.BBViewFilter = "5"
			context.user_preferences.edit.use_global_undo = True
		except Exception as E:
			s = "Generate EP Visualization Failed: " + str(E)
			self.report('ERROR', s)
			print (s)
			errorNotifier(text=s)
			return {'CANCELLED'}
		else:
			return{'FINISHED'}

class BBOperatorEPClear(types.Operator):
	bl_idname = "BBOperatorEPClear"
	bl_label = "Clear EP"
	bl_description = "Clear the EP Visualization"
	def invoke(self, context, event):
		try:
			context.user_preferences.edit.use_global_undo = False
			cleanEPObjs()
			context.user_preferences.edit.use_global_undo = True
		except Exception as E:
			s = "Clear EP Visualization Failed: " + str(E)
			self.report('ERROR', s)
			print (s)
			errorNotifier(text=s)
			return {'CANCELLED'}
		else:
			return{'FINISHED'}


class BBOperatorExport(types.Operator):
	bl_idname = "BBOperatorExport"
	bl_label = "Export PDB"
	bl_description = "Export current view to PDB"
	def invoke(self, context, event):
		try:
			context.user_preferences.edit.use_global_undo = False
			exportSequence(PDBOnly = True)
			context.user_preferences.edit.use_global_undo = True
		except Exception as E:
			s = "Export PDB Failed: " + str(E)
			self.report('ERROR', s)
			print (s)
			errorNotifier(text=s)
			return {'CANCELLED'}
		else:
			return{'FINISHED'}


class BBOperatorAnim(types.Operator):
	bl_idname = "BBOperatorAnim"
	bl_label = "Export Movie"
	bl_description = "Make a movie"
	def invoke(self, context, event):
		try:
			context.user_preferences.edit.use_global_undo = False
			exportSequence()
			context.user_preferences.edit.use_global_undo = True
		except Exception as E:
			s = "Export Movie Failed: " + str(E)
			self.report('ERROR', s)
			print (s)
			errorNotifier(text=s)
			return {'CANCELLED'}
		else:
			return{'FINISHED'}

