import time, os, pickle, shutil, math
from bpy import *
#####################################################################
# Start of user-editable settings
#####################################################################

# third party exe path, leave empty for auto search
pyMolPath = ""
pyPath = ""

# list of path to search
pyMolPathSearch = [
"%programfiles%\\PyMOL\\PyMOL\\PymolWin.exe",
"%programfiles%\\DeLano Scientific\\PyMOL Eval\\PymolWin.exe",
"%programfiles%\\DeLano Scientific\\PyMOL\\PymolWin.exe",
"%programfiles(x86)%\\PyMOL\\PyMOL\\PymolWin.exe",
"%programfiles(x86)%\\DeLano Scientific\\PyMOL Eval\\PymolWin.exe",
"%programfiles(x86)%\\DeLano Scientific\\PyMOL\\PymolWin.exe",
]

pyPathSearch = [
"%systemdrive%\\Python27\\python.exe",
"%systemdrive%\\Python26\\python.exe",
"%systemdrive%\\Python25\\python.exe",
]


#Define common atom name as variables to avoid RSI from typing quotes
C = "C"
N = "N"
O = "O"
S = "S"
H = "H"
CA = "CA"
P = "P"
FE = "FE"
MG = "MG"
ZN = "ZN"
CU = "CU"
NA = "NA"
K = "K"
CL = "CL"
MN = "MN"
F = "F"


# Define atom scales [visual Van der Waals scale, collision radius scale]

scale_vdw={C:[1.35,0.6], CA:[1.59,0.6], N:[1.23,0.6], O:[1.2,0.6], S:[1.43,0.6], P:[1.43,0.6], FE:[1.59,0.6], MG:[1.37,0.6], ZN:[1.1,0.6], CU:[1.1,0.6], NA:[1.8,0.6], K:[2.18,0.6], CL:[1.37,0.6], MN:[1.59,0.6], H:[0.95,0.4], F:[1.16, 0.6]}

# Define atom scales [visual covalent scale, collision radius scale]

scale_cov={C:[1.1,0.6], CA:[0.99,0.6], N:[1.07,0.6], O:[1.04,0.6], S:[1.46,0.6], P:[1.51,0.6], FE:[0.64,0.6], MG:[0.65,0.6], ZN:[0.74,0.6], CU:[0.72,0.6], NA:[0.95,0.6], K:[1.33,0.6], CL:[1.81,0.6], MN:[0.46,0.6], H:[0.53,0.4], F:[1.36, 0.6]}

# Define atom color [R,G,B]
color={C:[0.1,0.1,0.1], CA:[0.4,1.0,0.14], N:[0.24,0.41,0.7], O:[0.46,0.1,0.1], S:[1.0,0.75,0.17], P:[1.0,0.37,0.05], FE:[1.0,0.5,0.0], MG:[0.64,1.0,0.05], ZN:[0.32,0.42,1], CU:[1.0,0.67,0.0], NA:[0.8,0.48,1.0], K:[0.72,0.29,1.0], CL:[0.1,1.0,0.6], MN:[0.67,0.6,1.0], H:[0.9,0.9,0.9], F:[0.27, 0.8, 0.21]}

maxCurveSet = 4

#####################################################################
# End of user-editable settings
#####################################################################


# blender binary Path
blenderPath = app[2]

# naive os detection
if os.sep == "/":
	linux = True
else:
	linux = False


if linux:
	# set homepath (linux)
	homePath = utils.script_paths()[0] + "/ui/BioBlender/"
	print ("detectPathLinux Not implemented")
else:
	from winreg import ExpandEnvironmentStrings
	# set homepath (windows)
	homePath = utils.script_paths()[0] + "\\ui\\BioBlender\\"
	# auto detect pymol path
	if not pyMolPath:
		for i in pyMolPathSearch:
			if os.path.exists(ExpandEnvironmentStrings(i)):
				pyMolPath = ExpandEnvironmentStrings(i)
				break
	# auto detect python path
	if not pyPath:
		for i in pyPathSearch:
			if os.path.exists(ExpandEnvironmentStrings(i)):
				pyPath = ExpandEnvironmentStrings(i)
				break

#####################################################################
# Contains storage space for global variables
#####################################################################



# initialization
def init():
	context.user_preferences.themes[0].view_3d.back = [0.7,0.7,0.7]				# better visibility
	context.user_preferences.edit.keyframe_new_interpolation_type = 'LINEAR'	# better motion
	context.user_preferences.view.show_view_name = False						# cleaner interface
	context.user_preferences.view.show_mini_axis = False						# cleaner interface
	context.user_preferences.view.use_rotate_around_active = True				# easier to navigate
	context.user_preferences.system.use_vertex_buffer_objects = True			# VBO gives much better viewport performance
	


# select obj and make it active, deselect everything else
def select(obj):
	try:
		ob=data.objects[obj]
		ops.object.select_all(action="DESELECT")
		ob.select = True
		context.scene.objects.active=ob
	except:
		return None
	else:
		return ob


# validate and get the number of models in the BBImportOrder string
def getNumModel():
	scene = context.scene
	try:
		list = [int(model) for model in scene.BBImportOrder.split(',')]
		return len(list)
	except:
		return -1


# Set the draw mode of the viewport
def setViewShading(drawtype):
	for area in data.window_managers['WinMan'].windows[0].screen.areas:
		if area.type == "VIEW_3D":
			area.spaces[0].viewport_shade = drawtype



# delete EP related objects
def cleanEPObjs(deletionList = None):
	ops.object.select_all(action="DESELECT")
	# use deletionList if supplied
	if deletionList:
		for obj in deletionList:
			obj.select = True
	# otherwise delete everything in EPOBJ list
	else:
		for list in store.epOBJ:
			for obj in list:
				obj.select = True
		store.epOBJ = []
	# call delete operator
	ops.object.delete()


# render a single frame and save
def renderSingle(i):
	context.scene.frame_end = i
	context.scene.frame_start = i
	ops.render.render(animation = True)



# return center of atom cluster
def atomCentre():
	sum = [0,0,0]
	n = 0
	for ob in data.objects:
		if ob.BBInfo != "":
			sum[0] += ob.location[0]
			sum[1] += ob.location[1]
			sum[2] += ob.location[2]
			n += 1
	return [i/n for i in sum]


# launch app in separate process, for better performance on multithreaded computers
def launch(exeName, async = False):
	# try to hide window (does not work recursively)
	startupinfo = subprocess.STARTUPINFO()
	startupinfo.dwFlags |= subprocess.STARTF_USESHOWWINDOW
	startupinfo.wShowWindow = subprocess.SW_HIDE
	
	if async:
		# if running in async mode, return (the process object) immediately
		return subprocess.Popen(exeName, bufsize=8192, startupinfo=startupinfo)
	else:
		# otherwise wait until process is finished (and return None)
		subprocess.call(exeName, bufsize=8192, startupinfo=startupinfo)
		return None


# Wait until process finishes
def wait(process):
	while process.poll() == None:
		time.sleep(0.1)
		# needed if io mode is set to subprocess.PIPE to avoid deadlock
		# process.communicate()



# returns absolute path from relative path
absPath = path.abspath

def makeRope(verbose = False):
	#start = time.time()
	#print("importFile")
	# Start with a clean slate
	objName="atomFill"
	ops.object.select_all(action="DESELECT")
	context.scene.objects.active = None

	# alias
	scene = context.scene
	filePath = absPath(scene.BBImportPath)
	id = scene.BBModelRemark
	extension = filePath.lower().endswith
	# Parse text files sequenc
	try:
		# Append atom object from external file and create atom object for each element
		if linux:
			path = homePath+"data/Ropelibrary.blend/Object/"
		else:
			path = homePath+"data\\Ropelibrary.blend\\Object\\"
		ops.wm.link_append(filepath = path + objName, filename = objName, directory = path, link = False)
		data.objects[objName].name ="elementrope"
		context.scene.objects.active = data.objects["elementrope"]
		context.active_object.layers = context.scene.layers
	except Exception as E:
		raise Exception ("Template element object cannot be loaded from library: ", E)



	# Make high res atom model
	if scene.BBHighQuality:
		ops.object.editmode_toggle()
		ops.mesh.subdivide(number_cuts=1, smoothness=1)
		ops.object.editmode_toggle()

	# Build 3D scene from modelList
	curFrame=1
		# reset
	ops.object.select_all(action="DESELECT")
	scene.objects.active = None
	scene.frame_set(curFrame)


	# on first model, Place atoms in scene
	if curFrame == 1:
		#modelCopy = model.copy()

		# select template atom
		data.objects["elementrope"].hide = False
		data.objects["elementrope"].select = True

		# temporary rename template atom
		#data.objects["elementrope"].name = id

		try:
			# (count - 1) because there is the original template object.
			print ("Making 5 objects")
			ops.object.duplicate(linked = not scene.BBSingleUser, mode=1, copies = 6-1)
		except Exception as E:
			# We are using a specially patched version of the duplicate operator that is faster
			raise Exception ("Warning: Fast duplicate instancing is not supported by this version of Blender. Trying Brute Force approach.",E)
			for i in range(5):
				ops.object.duplicate(linked = not scene.BBSingleUser, mode=1)
		try:
			# (count - 1) because there is the original template object.
			print ("Making 5 empiets")
			ops.object.add(type='EMPTY', view_align=False, enter_editmode=False, location=(0.0, 0.0, 0.0), rotation=(0.0, 0.0, 0.0))
			ops.object.duplicate(linked = not scene.BBSingleUser, mode=1, copies = 6-1)
		except Exception as E:
			# We are using a specially patched version of the duplicate operator that is faster
			raise Exception ("Warning: Fast duplicate instancing is not supported by this version of Blender. Trying Brute Force approach.",E)
			for i in range(5):
				ops.object.duplicate(linked = not scene.BBSingleUser, mode=1)

		try:
			# # walk through list of objects and set name, location and material for each atom
			counterels=0
			counterems=0
			for i, obj in enumerate(data.objects):
				# print("obj name" + obj.name)
				# # if the object is the one of those we just created (i.e. if name matches xx.0000)
				
				if obj.name[0:11]=="elementrope":
					#obj.material_slots[0].material = data.materials[index]
					#obj.scale = [scale_vdw[index][0], scale_vdw[index][0], scale_vdw[index][0]]
					obj.location=[0,0,0]
					obj.location=[counterels*(-1.8),0,0]
					counterels=counterels+1
				if obj.name[0:5]=="Empty":
					#obj.material_slots[0].material = data.materials[index]
					# if obj.name=="Empty":
						# print("I'm scaling")
						# #ops.object.select_name(name="Empty", extend=False)
						# obj.scale[0]=4
						# obj.scale[1]=4
						# obj.scale[2]=4
						# ops.object.scale_apply()
					obj.location=[0,0,0]
					obj.location=[counterems*(-1.8),0,0]
					counterems=counterems+1
						# obj.game.radius = scale_vdw[index][1]
					# else:
						# obj.scale = [scale_cov[index][0], scale_cov[index][0], scale_cov[index][0]]
						# obj.game.radius = scale_cov[index][1]						
					# # add atom info as RNA string to each object
					# obj.BBInfo = entry[1][:]
			# #scene.BBChainImported=Chain_atoms

		except Exception as E:
			raise Exception ("Unable to generate 3D model from PDB File", E)
		try:
			# # walk through list of objects and set name, location and material for each atom
			counterels=0
			counterems=0
			for i, obj in enumerate(data.objects):
				if obj.name[0:11]=="elementrope":
					if obj.name=="elementrope":
						ops.object.select_all(action="DESELECT")
						ops.object.select_name(name=obj.name, extend=False)
						ops.object.select_name(name="Empty", extend=True)
						ops.object.parent_set(type='OBJECT')
						emptytarget="Empty.001"
						obj.constraints["TrackTo"].target = data.objects[emptytarget]
					else:
						emptyname="Empty."+obj.name.split(".")[1]
						ops.object.select_all(action="DESELECT")
						print(obj.name,emptyname)
						ops.object.select_name(name=obj.name, extend=False)
						ops.object.select_name(name=emptyname, extend=True)
						ops.object.parent_set(type='OBJECT')
						emptytarget="Empty"+".00"+str(int(obj.name.split(".")[1])+1)
						obj.constraints["TrackTo"].target = data.objects[emptytarget]
				if obj.name[0:5]=="Empty" and obj.name!="Empty":
					if obj.name=="Empty.001":
						ops.object.select_all(action="DESELECT")
						ops.object.select_name(name=obj.name, extend=False)
						ops.object.select_name(name="elementrope", extend=True)
						ops.object.parent_set(type='OBJECT')
					else:
						elementname="elementrope"+".00"+str(int(obj.name.split(".")[1])-1)
						ops.object.select_all(action="DESELECT")
						#print(obj.name,elementname)
						ops.object.select_name(name=obj.name, extend=False)
						ops.object.select_name(name=elementname, extend=True)
						ops.object.parent_set(type='OBJECT')
				# print("obj name" + obj.name)
				# # # if the object is the one of those we just created (i.e. if name matches xx.0000)
				# if obj.name[0:11]=="elementrope":
					# #gli elementi vanno imparentati all'empty corrispondente
					# if obj.name=="elementrope":
						# print (obj.name + " " +"Empty")
						# ops.object.select_name(name=obj.name, extend=False)
						# ops.object.select_name(name="Empty", extend=True)
						# ops.object.parent_set(type='OBJECT')
					# else:
						# numempty=obj.name.split(".")[1]
						# print (obj.name + " " +"Empty."+numempty)
						# ops.object.select_name(name=obj.name, extend=False)
						# ops.object.select_name(name="Empty."+numempty, extend=True)
						# ops.object.parent_set(type='OBJECT')
		except Exception as E:
			raise Exception ("Unable to generate 3D model from PDB File", E)


		#if verbose: print ("Build time: " + str(time.time() - start))
makeRope()