#####################################################################
# Contains some of the more complicated file loading / conversion procedure
#####################################################################

from bpy import *
from .helpers import *
from . import store

# import curve description text into Blender
def importEP(path):
	store.curveCount = 0
	scene = context.scene
	pts = []
	objList = []
	# read the file once to generate curves
	with open(path,"r") as file:
		for file_line in file:
			line=file_line.split()
			if line[0]=="n":
				if store.curveCount !=0:
					# for every n encountered creates a new curve
					cu = data.curves.new("Curve%3d"%store.curveCount, "CURVE")
					ob = data.objects.new("CurveObj%3d"%store.curveCount, cu)
					scene.objects.link(ob)
					scene.objects.active = ob
					# set all the properties of the curve
					spline = cu.splines.new("NURBS")
					cu.dimensions = "3D"
					cu.use_path = True
					cu.resolution_u = 1
					spline.points.add(len(pts)//4-1)
					spline.points.foreach_set('co', pts)
					spline.use_endpoint_u = True
					ob.field.type="GUIDE"
					ob.field.use_max_distance=True
					ob.field.distance_max=0.05
					# objList keeps a list of all EP related objects for easy deletion
					objList.append(ob)
					pts = []
				store.curveCount += 1
			elif line[0]=="v":
				pts.append(float(line[1]))
				pts.append(float(line[2]))
				pts.append(float(line[3]))
				pts.append(1)

	# rename current emitter
	if select("Emitter"):
		for list in store.epOBJ:
			for obj in list:
				if obj.name == "Emitter":
					obj.name = "Emitter%d"%store.curveCount


	# read the file again to generate the particle emitter object
	with open(path,"r") as file:
		verts=[]
		for line in file:
			# read the first line after each 'n' identifier
			if "n" in line:
				next = file.readline()
				coord = next.split()
				verts.append([float(i) for i in coord[1:]])

		# make mesh
		mesh = data.meshes.new("Emitter")
		mesh.from_pydata(verts[:-1], [], [])		# [:-1] to fix the off by one error somewhere...

		# append emitter object with particle sytem into scene, and assign mesh to the object
		# this is a workaround to avoid having to add a particle system from the scene context (impossible)
		if linux:
			path = homePath+"data/library.blend/Object/"
		else:
			path = homePath+"data\\library.blend\\Object\\"

		ops.wm.link_append(filepath = path + "Emitter", filename = "Emitter", directory = path, link = False)
		ob = select("Emitter")
		ob.data = mesh

		# add material if does not exist
		if not ob.data.materials:
			mat = data.materials["Particles"]
			#ob.data.add_material(mat)
			ob.data.materials.append(mat)

		# change particle density according to curve count
		ob.particle_systems[0].settings.count = int(context.scene.BBEPNumOfLine * 50000 * context.scene.BBEPParticleDensity)
		# reset location
		ob.location = [0,0,0]
		# add object to deletion list
		objList.append(ob)

	return objList






# Convert WRL to OBJ for scivis.exe
def exportOBJ(path):
	vertexData = []		# list of list[3] (wrl vertices data)
	# read wrl file
	with open(path+".wrl") as wrl:
		found = False
		for line in wrl:
			# skip to coord section of the file
			if not found:
				if "coord" in line:
					wrl.readline()
					found = True
			# when in the coord section of the file
			else:
				if "]" not in line:
					# convert vertexData from string to a list of float
					entry = line[:-2].split()
					entryFloat = [float(coord) for coord in entry]
					vertexData.append(entryFloat)
				else:
					# end document processing
					break

	# write obj file: vertex data
	with open(path+".obj", mode="w") as obj:
		for entry in vertexData:
			out = "v %f %f %f\n" % (entry[0], entry[1], entry[2])
			obj.write(out)

		# face data
		i = 0
		while (i < len(vertexData)):
			out = "f %d/%d %d/%d %d/%d\n" % (i+1,i+1,i+2,i+2,i+3,i+3)
			obj.write(out)
			i = i + 3




# lookup sidechain parents
def bondLookUp(atom, amac):
	if (atom=="O" or atom=="OXT"):
			parent = ["C",C]
	elif (atom=="CB" or atom=="HA" or atom=="HA2" or atom=="HA3"):
			parent = ["CA",C]
	elif  (atom=="SG" or "HB" in atom or "OG" in atom or "CG" in atom):
			parent = ["CB",C]
	elif (atom=="H" or atom=="H1" or atom=="H2" or atom=="H3"):
			parent = ["N",N]
	elif (atom=="HG1"):
			parent = ["OG1",O]
	elif (atom=="HG23" or atom=="HG22" or atom=="HG21"):
			parent = ["CG2",C]
	elif (atom=="SD" or "CD" in atom or "ND" in atom or atom=="HG2" or atom=="HG3" or atom=="OD1" or atom=="OD2" or atom=="HG12" or atom=="HG13" or atom=="HG13"):
			if (amac=="ILE" or amac=="VAL"):
				parent = ["CG1",C]
			else:
				parent = ["CG",C]
	elif (atom=="CE2" or atom=="CE3" or atom=="NE2" or atom=="HD2"):
			if (amac=="GLN"):
				parent = ["CD",C]
			elif (amac=="ARG" or amac=="LYS" or amac=="PRO"):
				parent = ["CD",C]
			elif(amac=="ASP"):
				parent = ["OD2",O]
			else:
				parent = ["CD2",C]
	elif (atom=="CE1" or atom=="HD11" or atom=="HD12" or atom=="HD13" or atom=="HD1" or atom=="NE1"):
			if (amac=="HIS"):
				parent = ["ND1",N]
			else:
				parent = ["CD1",C]
	elif (atom=="NE" or atom=="HD3" or atom=="CE" or atom=="OE1" or atom=="OE2"):
			if (amac=="MET"):
				parent = ["SD",S]
			else:
				parent = ["CD",C]
	elif (atom=="CZ" or atom=="HE" or atom=="HE1"):
			if (amac=="ARG"):
				parent = ["NE",N]
			elif (amac=="TRP"):
				parent = ["NE1",N]
			elif (amac=="MET"):
				parent = ["CE",C]
			elif (amac=="PHE" or amac=="HIS" or amac=="TYR"):
				parent = ["CE1",C]
	elif (atom=="NH1" or atom=="NH2" or atom=="HZ" or atom=="OH"):
			parent = ["CZ",C]
	elif (atom=="HH11" or atom=="HH12" or atom=="1HH1" or atom=="1HH2"):
			parent = ["NH1",N]
	elif (atom=="HH21" or atom=="HH22" or atom=="2HH2" or atom=="1HH2"):
			parent = ["NH2",N]
	elif (atom=="HD21" or atom=="HD22" or atom=="HD23"):
			if (amac=="LEU"):
				parent = ["CD2",C]
			else:
				parent = ["ND2",N]
	elif (atom=="HE3"  or atom=="NZ"):
			if (amac=="TRP"):
				parent = ["CE3",C]
			else:
				parent = ["CE",C]
	elif (atom=="HZ1" or atom=="HZ2" or atom=="HZ3"):
			if (amac=="TRP" and atom=="HZ2"):
				parent = ["CZ2",S]
			elif (amac=="TRP" and atom=="HZ3"):
				parent = ["CZ3",S]
			else:
				parent = ["NZ",N]
	elif (atom=="HG"):
			if (amac=="LEU"):
				parent = ["CG",C]
			if (amac=="CYS"):
				parent = ["SG",S]
			else:
				parent = ["OG",O]
	elif (atom=="HE2" or atom=="CZ2" or atom=="HE21" or atom=="HE22"):
			if (amac=="HIS" or amac=="GLN"):
				parent = ["NE2",N]
			elif (amac=="PHE" or amac=="TYR" or amac=="TRP"):
				parent = ["CE2",C]
			elif (amac=="GLU"):
				parent = ["OE2",O]
			elif (amac=="MET" or amac=="LYS"):
				parent = ["CE",C]
	elif (atom=="HH"):
			parent = ["OH",O]
	elif (atom=="CZ3"):
			parent = ["CE3",C]
	elif (atom=="CH2" ):
			parent = ["CZ2",C]
	elif (atom=="HH2"):
			parent = ["CH2",C]
	return parent





class PDBString(str):
	# Parses PDB line using column attribute
	# file definition is taken from www.wwpdb.org/documentation/format32/sect9.html
	# The function tries to be smart by striping out whitespaces
	# and converts certain properties to list
	def get(self, property):
		if property == "tag": return self[0:6].strip()
		if property == "serial": return self[6:11].strip()
		if property == "name": return self[12:16].strip()
		if property == "altLoc": return self[16:17].strip()
		if property == "aminoName": return self[17:20].strip()
		if property == "chainID": return self[21:22].strip()
		if property == "chainSeq": return self[22:26].strip()
		if property == "iCode": return self[26:27].strip()
		if property == "loc": return [float(coord) for coord in self[30:54].split()]
		if property == "occupancy": return self[54:60].strip()
		if property == "tempFactor": return self[60:66].strip()
		if property == "element": return self[76:78].strip()
		if property == "charge": return self[78:80].strip()
		if property == "modelID": return int(self[6:20].strip())
		# if no match found:
		return None

	# insert data into a 80 column pdb string
	def set(self,loc,prop):
		# insert prop into self[loc], but not changing the length of the string
		newStr = self[0:loc] + str(prop) + self[loc+len(str(prop)):]
		return PDBString(newStr)


	