import time, os, pickle, shutil, math
from bpy import *
from . import store
from .settings import *
from .parsers import *
from .helpers import *



# create grains as empty with a name
def createGrain(name,integer,loc):
    ops.object.add(type='EMPTY', location=loc)
    data.objects['Empty'].name = name+integer
    return

def grainMain():
	scene = context.scene
	viewMode = scene.BBViewFilter
		# store.modelContainer is where all the data for the imported PDB is stored.
		# activetag is the name of the selected/active protein model
		#(because we could have multiple models loaded), we only want to operate on one.
	Aloc = [0,0,0]
	Bloc = [0,0,0]
	Gloc = [0,0,0]
	G1loc = [0,0,0]
	G2loc = [0,0,0]
	Dloc = [0,0,0]
	D1loc = [0,0,0]
	D2loc = [0,0,0]
	Eloc = [0,0,0]
	E1loc = [0,0,0]
	E2loc = [0,0,0]
	E3loc = [0,0,0]
	Zloc = [0,0,0]
	Z3loc = [0,0,0]
	Hloc = [0,0,0]
	H1loc = [0,0,0]
	H2loc = [0,0,0]
	model = store.modelContainer[store.activeTag]
	# this "for .. in..." line loops through each atom in the protein
	for objName, BBInfo in model.items():
	# objName is the blender object name of the atom
		# BBInfo is the PDBString class of that atom
		if BBInfo.get("aminoName")=="ALA" and BBInfo.get("name")=="CA":
			resno = BBInfo.get("chainSeq")
			Aloc = BBInfo.get("loc")             # this is a 3-item list (xyz)
			createGrain("ALAca", resno, Aloc)
		if BBInfo.get("aminoName")=="ARG":
			resno = BBInfo.get("chainSeq")
			if BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CA":
				Aloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CB":
				Bloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CG":
				Gloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CD":
				Dloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="NE":
				Eloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CZ":
				Zloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="NH1":
				H1loc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="NH2":
				H2loc = BBInfo.get("loc")
				createGrain("ARGca", resno, Aloc)
				createGrain("ARGlip", resno, [(Bloc[0]+Gloc[0]+Dloc[0])/3,(Bloc[1]+Gloc[1]+Dloc[1])/3,(Bloc[2]+Gloc[2]+Dloc[2])/3])
				createGrain("ARGpos", resno, [(Eloc[0]+Zloc[0]+H1loc[0])/3,(Eloc[1]+Zloc[1]+H1loc[1])/3,(Eloc[2]+Zloc[2]+H1loc[2])/3])
				createGrain("ARGhyd", resno, H2loc)
		if BBInfo.get("aminoName")=="ASN":
			resno = BBInfo.get("chainSeq")
			if BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CA":
				Aloc = BBInfo.get("loc")
				createGrain("ASNca", resno, Aloc)
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CB":
				Bloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CG":
				Gloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="OD1":
				D1loc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="ND2":
				D2loc = BBInfo.get("loc")
				createGrain("ASNlip", resno, [(Bloc[0]+Gloc[0])/2,(Bloc[1]+Gloc[1])/2,(Bloc[2]+Gloc[2])/2])
				createGrain("ASNhyd", resno, [(D1loc[0]+D2loc[0])/2,(D1loc[1]+D2loc[1])/2,(D1loc[2]+D2loc[2])/2])
		if BBInfo.get("aminoName")=="ASP":
			resno = BBInfo.get("chainSeq")
			if BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CA":
				Aloc = BBInfo.get("loc")
				createGrain("ASPca", resno, Aloc)
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CB":
				Bloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CG":
				Gloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="OD1":
				D1loc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="OD2":
				D2loc = BBInfo.get("loc")
				createGrain("ASPlip", resno, [(Bloc[0]+Gloc[0])/2,(Bloc[1]+Gloc[1])/2,(Bloc[2]+Gloc[2])/2])
				createGrain("ASPneg", resno, [(D1loc[0]+D2loc[0])/2,(D1loc[1]+D2loc[1])/2,(D1loc[2]+D2loc[2])/2])
		if BBInfo.get("aminoName")=="CYS":
			resno = BBInfo.get("chainSeq")
			if BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CA":
				Aloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CB":
				Bloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="SG":
				Gloc = BBInfo.get("loc")
				createGrain("CYSca", resno, Aloc)
				createGrain("CYSlip", resno, [(Bloc[0]+Gloc[0])/2,(Bloc[1]+Gloc[1])/2,(Bloc[2]+Gloc[2])/2])
		if BBInfo.get("aminoName")=="GLY":
			resno = BBInfo.get("chainSeq")
			if BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CA":
				Aloc = BBInfo.get("loc")
				createGrain("GLYca", resno, Aloc)
		if BBInfo.get("aminoName")=="GLN":
			resno = BBInfo.get("chainSeq")
			if BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CA":
				Aloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CB":
				Bloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CG":
				Gloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CD":
				Dloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="OE1":
				E1loc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="NE2":
				E2loc = BBInfo.get("loc")
				createGrain("GLNca", resno, Aloc)
				createGrain("GLNlip", resno, [(Bloc[0]+Gloc[0])/2,(Bloc[1]+Gloc[1])/2,(Bloc[2]+Gloc[2])/2])
				createGrain("GLNhyd", resno, [(Dloc[0]+E1loc[0]+E2loc[0])/3,(Dloc[1]+E1loc[1]+E2loc[1])/3,(Dloc[2]+E1loc[2]+E2loc[2])/3])
		if BBInfo.get("aminoName")=="GLU":
			resno = BBInfo.get("chainSeq")
			if BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CA":
				Aloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CB":
				Bloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CG":
				Gloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CD":
				Dloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="OE1":
				E1loc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="OE2":
				E2loc = BBInfo.get("loc")
				createGrain("GLUca", resno, Aloc)
				createGrain("GLUlip", resno, [(Bloc[0]+Gloc[0])/2,(Bloc[1]+Gloc[1])/2,(Bloc[2]+Gloc[2])/2])
				createGrain("GLUneg", resno, [(Dloc[0]+E1loc[0]+E2loc[0])/3,(Dloc[1]+E1loc[1]+E2loc[1])/3,(Dloc[2]+E1loc[2]+E2loc[2])/3])
		if BBInfo.get("aminoName")=="HYS":
			resno = BBInfo.get("chainSeq")
			if BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CA":
				Aloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CB":
				Bloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CG":
				Gloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="ND1":
				D1loc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CD2":
				D2loc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CE1":
				E1loc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="NE2":
				E2loc = BBInfo.get("loc")
				createGrain("HYSca", resno, Aloc)
				createGrain("HYSlip", resno, [(Bloc[0]+Gloc[0])/2,(Bloc[1]+Gloc[1])/2,(Bloc[2]+Gloc[2])/2])
				createGrain("HYShyd1", resno, [(D1loc[0]+E1loc[0])/2,(D1loc[1]+E1loc[1])/2,(D1loc[2]+E1loc[2])/2])
				createGrain("HYShyd2", resno, [(D2loc[0]+E2loc[0])/2,(D2loc[1]+E2loc[1])/2,(D2loc[2]+E2loc[2])/2])
		if BBInfo.get("aminoName")=="ILE":
			resno = BBInfo.get("chainSeq")
			if BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CA":
				Aloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CB":
				Bloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CG1":
				G1loc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CG2":
				G2loc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CD1":
				D1loc = BBInfo.get("loc")
				createGrain("ILEca", resno, Aloc)
				createGrain("ILElip1", resno, [(Bloc[0]+G2loc[0])/2,(Bloc[1]+G2loc[1])/2,(Bloc[2]+G2loc[2])/2])
				createGrain("ILElip2", resno, [(G1loc[0]+D1loc[0])/2,(G1loc[1]+D1loc[1])/2,(G1loc[2]+D1loc[2])/2])
		if BBInfo.get("aminoName")=="LEU":
			resno = BBInfo.get("chainSeq")
			if BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CA":
				Aloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CB":
				Bloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CG":
				Gloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CD1":
				D1loc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CD2":
				D2loc = BBInfo.get("loc")
				createGrain("LEUca", resno, Aloc)
				createGrain("LEUlip1", resno, [(Bloc[0]+Gloc[0])/2,(Bloc[1]+Gloc[1])/2,(Bloc[2]+Gloc[2])/2])
				createGrain("LEUlip2", resno, [(D1loc[0]+D2loc[0])/2,(D1loc[1]+D2loc[1])/2,(D1loc[2]+D2loc[2])/2])
		if BBInfo.get("aminoName")=="LYS":
			resno = BBInfo.get("chainSeq")
			if BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CA":
				Aloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CB":
				Bloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CG":
				Gloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CE":
				Eloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="NZ":
				Zloc = BBInfo.get("loc")
				createGrain("LYSca", resno, Aloc)
				createGrain("LYSlip", resno, Gloc)
				createGrain("LYSpos", resno, [(Eloc[0]+Zloc[0])/2,(Eloc[1]+Zloc[1])/2,(Eloc[2]+Zloc[2])/2])
		if BBInfo.get("aminoName")=="MET":
			resno = BBInfo.get("chainSeq")
			if BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CA":
				Aloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CB":
				Bloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CG":
				Gloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="SD":
				Dloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CE":
				Eloc = BBInfo.get("loc")
				createGrain("METca", resno, Aloc)
				createGrain("METlip1", resno,  [(Bloc[0]+Gloc[0])/2,(Bloc[1]+Gloc[1])/2,(Bloc[2]+Gloc[2])/2])
				createGrain("METlip2", resno, [(Dloc[0]+Eloc[0])/2,(Dloc[1]+Eloc[1])/2,(Dloc[2]+Eloc[2])/2])
		if BBInfo.get("aminoName")=="PHE":
			resno = BBInfo.get("chainSeq")
			if BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CA":
				Aloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CB":
				Bloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CG":
				Gloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CD1":
				D1loc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CE1":
				E1loc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CE2":
				E2loc = BBInfo.get("loc")
				createGrain("PHEca", resno, Aloc)
				createGrain("PHElip1", resno, [(Bloc[0]+Gloc[0])/2,(Bloc[1]+Gloc[1])/2,(Bloc[2]+Gloc[2])/2])
				createGrain("PHElip2", resno, [(D1loc[0]+E1loc[0])/2,(D1loc[1]+E1loc[1])/2,(D1loc[2]+E1loc[2])/2])
				createGrain("PHElip3", resno, E2loc)
		if BBInfo.get("aminoName")=="PRO":
			resno = BBInfo.get("chainSeq")
			if BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CA":
				Aloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CG":
				Gloc = BBInfo.get("loc")
				createGrain("PROca", resno, Aloc)
				createGrain("PROlip", resno, Gloc)
		if BBInfo.get("aminoName")=="SER":
			resno = BBInfo.get("chainSeq")
			if BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CA":
				Aloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CB":
				Bloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="OG":
				Gloc = BBInfo.get("loc")
				createGrain("SERca", resno, Aloc)
				createGrain("SERhyd", resno, [(Bloc[0]+Gloc[0])/2,(Bloc[1]+Gloc[1])/2,(Bloc[2]+Gloc[2])/2])
		if BBInfo.get("aminoName")=="THR":
			resno = BBInfo.get("chainSeq")
			if BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CA":
				Aloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CB":
				Bloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="OG1":
				G1loc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CG2":
				G2loc = BBInfo.get("loc")
				createGrain("THRca", resno, Aloc)
				createGrain("THRhyd", resno, [(Bloc[0]+G1loc[0]+G2loc[0])/3,(Bloc[1]+G1loc[1]+G2loc[1])/3,(Bloc[2]+G1loc[2]+G2loc[2])/3])
		if BBInfo.get("aminoName")=="TRP":
			resno = BBInfo.get("chainSeq")
			if BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CA":
				Aloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CB":
				Bloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CG":
				Gloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CD1":
				D1loc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CD2":
				D2loc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="NE1":
				E1loc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CE2":
				E2loc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CE3":
				E3loc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CZ2":
				Z2loc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CZ3":
				Z3loc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CH2":
				H2loc = BBInfo.get("loc")
				createGrain("TRPca", resno, Aloc)
				createGrain("TRPlip1", resno, [(Bloc[0]+Gloc[0])/2,(Bloc[1]+Gloc[1])/2,(Bloc[2]+Gloc[2])/2])
				createGrain("TRPhyd", resno, [(D1loc[0]+E1loc[0]+E2loc[0])/3,(D1loc[1]+E1loc[1]+E2loc[1])/3,(D1loc[2]+E1loc[2]+E2loc[2])/3])
				createGrain("TRPlip2", resno, [(D2loc[0]+E3loc[0]+Z3loc[0])/3,(D2loc[1]+E3loc[1]+Z3loc[1])/3,(D2loc[2]+E3loc[2]+Z3loc[2])/3])
				createGrain("TRPlip3", resno, [(Z2loc[0]+H2loc[0])/2,(Z2loc[1]+H2loc[1])/2,(Z2loc[2]+H2loc[2])/2])
		if BBInfo.get("aminoName")=="TYR":
			resno = BBInfo.get("chainSeq")
			if BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CA":
				Aloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CB":
				Bloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CG":
				Gloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CD1":
				D1loc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CD2":
				D2loc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CE1":
				E1loc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CE2":
				E2loc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CZ":
				Zloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="OH":
				Hloc = BBInfo.get("loc")
				createGrain("TYRca", resno, Aloc)
				createGrain("TYRlip1", resno, [(Bloc[0]+Gloc[0])/2,(Bloc[1]+Gloc[1])/2,(Bloc[2]+Gloc[2])/2])
				createGrain("TYRlip2", resno, [(D1loc[0]+E1loc[0])/2,(D1loc[1]+E1loc[1])/2,(D1loc[2]+E1loc[2])/2])
				createGrain("TYRlip3", resno, [(D2loc[0]+E2loc[0])/2,(D2loc[1]+E2loc[1])/2,(D2loc[2]+E2loc[2])/2])
				createGrain("TYRhyd", resno, [(Zloc[0]+Hloc[0])/2,(Zloc[1]+Hloc[1])/2,(Zloc[2]+Hloc[2])/2])
		if BBInfo.get("aminoName")=="VAL":
			resno = BBInfo.get("chainSeq")
			if BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CA":
				Aloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CB":
				Bloc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CG1":
				G1loc = BBInfo.get("loc")
			elif BBInfo.get("chainSeq")==resno and BBInfo.get("name")=="CG2":
				G2loc = BBInfo.get("loc")
				createGrain("VALca", resno, Aloc)
				createGrain("VALhyd", resno, [(Bloc[0]+G1loc[0]+G2loc[0])/3,(Bloc[1]+G1loc[1]+G2loc[1])/3,(Bloc[2]+G1loc[2]+G2loc[2])/3])
